# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetAggregateDeliveriesResult',
    'AwaitableGetAggregateDeliveriesResult',
    'get_aggregate_deliveries',
    'get_aggregate_deliveries_output',
]

@pulumi.output_type
class GetAggregateDeliveriesResult:
    """
    A collection of values returned by getAggregateDeliveries.
    """
    def __init__(__self__, aggregator_id=None, deliveries=None, id=None, ids=None, name_regex=None, names=None, output_file=None, status=None):
        if aggregator_id and not isinstance(aggregator_id, str):
            raise TypeError("Expected argument 'aggregator_id' to be a str")
        pulumi.set(__self__, "aggregator_id", aggregator_id)
        if deliveries and not isinstance(deliveries, list):
            raise TypeError("Expected argument 'deliveries' to be a list")
        pulumi.set(__self__, "deliveries", deliveries)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, int):
            raise TypeError("Expected argument 'status' to be a int")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="aggregatorId")
    def aggregator_id(self) -> str:
        return pulumi.get(self, "aggregator_id")

    @property
    @pulumi.getter
    def deliveries(self) -> Sequence['outputs.GetAggregateDeliveriesDeliveryResult']:
        return pulumi.get(self, "deliveries")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[int]:
        return pulumi.get(self, "status")


class AwaitableGetAggregateDeliveriesResult(GetAggregateDeliveriesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAggregateDeliveriesResult(
            aggregator_id=self.aggregator_id,
            deliveries=self.deliveries,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            status=self.status)


def get_aggregate_deliveries(aggregator_id: Optional[str] = None,
                             ids: Optional[Sequence[str]] = None,
                             name_regex: Optional[str] = None,
                             output_file: Optional[str] = None,
                             status: Optional[int] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAggregateDeliveriesResult:
    """
    This data source provides the Config Aggregate Deliveries of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.172.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.cfg.get_aggregate_deliveries(aggregator_id="example_value",
        ids=[
            "example_value-1",
            "example_value-2",
        ])
    pulumi.export("configAggregateDeliveryId1", ids.deliveries[0].id)
    ```


    :param str aggregator_id: The ID of the Aggregator.
    :param Sequence[str] ids: A list of Aggregate Delivery IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param int status: The status of the delivery method. Valid values: `0`: The delivery method is disabled. `1`: The delivery destination is enabled.
    """
    __args__ = dict()
    __args__['aggregatorId'] = aggregator_id
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:cfg/getAggregateDeliveries:getAggregateDeliveries', __args__, opts=opts, typ=GetAggregateDeliveriesResult).value

    return AwaitableGetAggregateDeliveriesResult(
        aggregator_id=pulumi.get(__ret__, 'aggregator_id'),
        deliveries=pulumi.get(__ret__, 'deliveries'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        status=pulumi.get(__ret__, 'status'))


@_utilities.lift_output_func(get_aggregate_deliveries)
def get_aggregate_deliveries_output(aggregator_id: Optional[pulumi.Input[str]] = None,
                                    ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                    name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                    output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                    status: Optional[pulumi.Input[Optional[int]]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAggregateDeliveriesResult]:
    """
    This data source provides the Config Aggregate Deliveries of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.172.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.cfg.get_aggregate_deliveries(aggregator_id="example_value",
        ids=[
            "example_value-1",
            "example_value-2",
        ])
    pulumi.export("configAggregateDeliveryId1", ids.deliveries[0].id)
    ```


    :param str aggregator_id: The ID of the Aggregator.
    :param Sequence[str] ids: A list of Aggregate Delivery IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param int status: The status of the delivery method. Valid values: `0`: The delivery method is disabled. `1`: The delivery destination is enabled.
    """
    ...
